@@ -27,12 +27,7 @@ from zenml.io import fileio
 from zenml.logger import get_logger
 from zenml.post_execution.pipeline import PipelineView
 from zenml.stacks.base_stack import BaseStack
-from zenml.utils.analytics_utils import (
-    FETCHED_STACK,
-    GET_PIPELINES,
-    SET_STACK,
-    track,
-)
+from zenml.utils.analytics_utils import GET_PIPELINES, SET_STACK, track
 
 logger = get_logger(__name__)
 
@@ -45,15 +40,14 @@ class Repository:
 
     def __init__(self, path: Optional[str] = None):
         """
-        Construct reference a ZenML repository.
+        Construct reference to a ZenML repository.
 
         Args:
             path (str): Path to root of repository
         """
         if path is None:
             try:
-                # Start from cwd and traverse up until find zenml config.
-                path = fileio.get_zenml_dir(os.getcwd())
+                path = fileio.get_zenml_dir()
             except InitializationException:
                 # If there isn't a zenml.config, use the cwd
                 path = os.getcwd()
@@ -151,9 +145,7 @@ class Repository:
                 ),
             )
 
-            # Make local stack active
-            gc = GlobalConfig()
-            gc.make_stack_active_for_repo(repo_path, "local_stack")
+            service.set_active_stack_key("local_stack")
 
     def get_git_wrapper(self) -> GitWrapper:
         """Returns the git wrapper for the repo."""
@@ -171,24 +163,15 @@ class Repository:
         Args:
             stack_key: Key of the stack to set active.
         """
-        gc = GlobalConfig()
-        self.service.get_stack(stack_key)  # check if it exists
-        gc.make_stack_active_for_repo(self.path, stack_key)
+        self.service.set_active_stack_key(stack_key)
 
-    @track(event=FETCHED_STACK)
     def get_active_stack_key(self) -> str:
         """Get the active stack key from global config.
 
         Returns:
             Currently active stacks key.
         """
-        gc = GlobalConfig()
-        if self.path not in gc.repo_active_stacks:
-            raise KeyError(
-                f"No active stack set for repo: {self.path}! Available "
-                f"stacks: {[(a, b) for a, b in gc.repo_active_stacks.items()]}."
-            )
-        return gc.repo_active_stacks[self.path]
+        return self.service.get_active_stack_key()
 
     def get_active_stack(self) -> BaseStack:
         """Get the active stack from global config.
