@@ -21,3 +21,5 @@ SKLEARN = "sklearn"
 TENSORFLOW = "tensorflow"
 PLOTLY = "plotly"
 FACETS = "facets"
+GRAPHVIZ = "graphviz"
+DASH = "dash"
