@@ -11,6 +11,12 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 #  or implied. See the License for the specific language governing
 #  permissions and limitations under the License.
+"""
+The Facets integration provides a simple way to visualise post-execution objects
+like `PipelineView`, `PipelineRunView` and `StepView`. These objects can be
+extended using the `BaseVisualization` class. This integration requires
+`facets-overview` be installed in your Python environment.
+"""
 
 from zenml.integrations.constants import FACETS
 from zenml.integrations.integration import Integration
