@@ -11,3 +11,10 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 #  or implied. See the License for the specific language governing
 #  permissions and limitations under the License.
+"""
+The configuration of each pipeline, step, backend, and produced artifacts are
+all tracked within the metadata store. The metadata store is an SQL database,
+and can be `sqlite` or `mysql`.
+
+Metadata are the pieces of information tracked about the pipelines, experiments and configurations that you are are running with ZenML. Metadata are stored inside the metadata store.
+"""
