@@ -40,14 +40,16 @@ from zenml.materializers.default_materializer_registry import (
     default_materializer_registry,
 )
 from zenml.steps.base_step_config import BaseStepConfig
+from zenml.steps.step_context import StepContext
 from zenml.steps.step_output import Output
 from zenml.steps.utils import (
     INTERNAL_EXECUTION_PARAMETER_PREFIX,
     PARAM_ENABLE_CACHE,
+    PARAM_PIPELINE_PARAMETER_NAME,
     SINGLE_RETURN_OUT_NAME,
     STEP_INNER_FUNC_NAME,
     _ZenMLSimpleComponent,
-    generate_component,
+    generate_component_class,
 )
 
 logger = get_logger(__name__)
@@ -72,6 +74,7 @@ class BaseStepMeta(type):
         cls.OUTPUT_SIGNATURE = {}
         cls.CONFIG_PARAMETER_NAME = None
         cls.CONFIG_CLASS = None
+        cls.CONTEXT_PARAMETER_NAME = None
 
         # Get the signature of the step function
         step_function_signature = inspect.getfullargspec(
@@ -127,6 +130,16 @@ class BaseStepMeta(type):
                     )
                 cls.CONFIG_PARAMETER_NAME = arg
                 cls.CONFIG_CLASS = arg_type
+            elif issubclass(arg_type, StepContext):
+                if cls.CONTEXT_PARAMETER_NAME is not None:
+                    raise StepInterfaceError(
+                        f"Found multiple context arguments "
+                        f"('{cls.CONTEXT_PARAMETER_NAME}' and '{arg}') when "
+                        f"trying to create step '{name}'. Please make sure to "
+                        f"only have one `StepContext` as input "
+                        f"argument for a step."
+                    )
+                cls.CONTEXT_PARAMETER_NAME = arg
             else:
                 # Can't do any check for existing materializers right now
                 # as they might get passed later, so we simply store the
@@ -162,24 +175,35 @@ T = TypeVar("T", bound="BaseStep")
 
 
 class BaseStep(metaclass=BaseStepMeta):
-    """The base implementation of a ZenML Step which will be inherited by all
-    the other step implementations"""
+    """Abstract base class for all ZenML steps.
+
+    Attributes:
+        step_name: The name of this step.
+        pipeline_parameter_name: The name of the pipeline parameter for which
+            this step was passed as an argument.
+        enable_cache: A boolean indicating if caching is enabled for this step.
+        requires_context: A boolean indicating if this step requires a
+            `StepContext` object during execution.
+    """
 
     # TODO [ENG-156]: Ensure these are ordered
     INPUT_SIGNATURE: ClassVar[Dict[str, Type[Any]]] = None  # type: ignore[assignment] # noqa
     OUTPUT_SIGNATURE: ClassVar[Dict[str, Type[Any]]] = None  # type: ignore[assignment] # noqa
     CONFIG_PARAMETER_NAME: ClassVar[Optional[str]] = None
     CONFIG_CLASS: ClassVar[Optional[Type[BaseStepConfig]]] = None
+    CONTEXT_PARAMETER_NAME: ClassVar[Optional[str]] = None
 
     def __init__(self, *args: Any, **kwargs: Any) -> None:
         self.step_name = self.__class__.__name__
+        self.pipeline_parameter_name: Optional[str] = None
         self.enable_cache = getattr(self, PARAM_ENABLE_CACHE)
+        self.requires_context = bool(self.CONTEXT_PARAMETER_NAME)
 
         self.PARAM_SPEC: Dict[str, Any] = {}
         self.INPUT_SPEC: Dict[str, Type[BaseArtifact]] = {}
         self.OUTPUT_SPEC: Dict[str, Type[BaseArtifact]] = {}
         self._explicit_materializers: Dict[str, Type[BaseMaterializer]] = {}
-        self.__component = None
+        self._component: Optional[_ZenMLSimpleComponent] = None
 
         self._verify_arguments(*args, **kwargs)
 
@@ -232,9 +256,12 @@ class BaseStep(metaclass=BaseStepMeta):
         return materializers
 
     @property
-    def _internal_execution_parameters(self) -> Dict[str, str]:
+    def _internal_execution_parameters(self) -> Dict[str, Any]:
         """ZenML internal execution parameters for this step."""
-        properties = {}
+        parameters = {
+            PARAM_PIPELINE_PARAMETER_NAME: self.pipeline_parameter_name
+        }
+
         if self.enable_cache:
             # Caching is enabled so we compute a hash of the step function code
             # and materializers to catch changes in the step behavior
@@ -244,19 +271,19 @@ class BaseStep(metaclass=BaseStepMeta):
                 source_code = inspect.getsource(value)
                 return hashlib.sha256(source_code.encode("utf-8")).hexdigest()
 
-            properties["step_source"] = _get_hashed_source(self.process)
+            parameters["step_source"] = _get_hashed_source(self.process)
 
             for name, materializer in self.get_materializers().items():
                 key = f"{name}_materializer_source"
-                properties[key] = _get_hashed_source(materializer)
+                parameters[key] = _get_hashed_source(materializer)
         else:
             # Add a random string to the execution properties to disable caching
             random_string = f"{random.getrandbits(128):032x}"
-            properties["disable_cache"] = random_string
+            parameters["disable_cache"] = random_string
 
         return {
             INTERNAL_EXECUTION_PARAMETER_PREFIX + key: value
-            for key, value in properties.items()
+            for key, value in parameters.items()
         }
 
     def _verify_arguments(self, *args: Any, **kwargs: Any) -> None:
@@ -463,9 +490,20 @@ class BaseStep(metaclass=BaseStepMeta):
                 f"json serializable parameter values."
             ) from e
 
-        self.__component = generate_component(self)(
-            **input_artifacts,
-            **execution_parameters,
+        # make sure we have registered materializers for each output
+        materializers = self.get_materializers(ensure_complete=True)
+
+        component_class = generate_component_class(
+            step_name=self.step_name,
+            step_module=self.__module__,
+            input_spec=self.INPUT_SPEC,
+            output_spec=self.OUTPUT_SPEC,
+            execution_parameter_names=set(execution_parameters),
+            step_function=self.process,
+            materializers=materializers,
+        )
+        self._component = component_class(
+            **input_artifacts, **execution_parameters
         )
 
         # Resolve the returns in the right order.
@@ -480,12 +518,12 @@ class BaseStep(metaclass=BaseStepMeta):
     @property
     def component(self) -> _ZenMLSimpleComponent:
         """Returns a TFX component."""
-        if not self.__component:
+        if not self._component:
             raise StepInterfaceError(
                 "Trying to access the step component "
                 "before creating it via calling the step."
             )
-        return self.__component
+        return self._component
 
     @abstractmethod
     def process(self, *args: Any, **kwargs: Any) -> Any:
